<?php
/**
 * Template: Event List Template
 *
 * This template renders each individual event in the events list.
 * To customize, copy this file to your-theme/vizou-events/vizou-events-list.php
 *
 * Available template tags:
 * - vizou_event_date() - Displays the event's start date
 * - vizou_event_end_date() - Displays the event's end date (for multi-day events)
 * - vizou_event_time() - Displays the event's time
 * - vizou_event_artist() - Displays the event's artist with optional link
 * - vizou_event_venue() - Displays the event's venue with optional link
 * - vizou_venue_street(), vizou_venue_city(), vizou_venue_province(), vizou_venue_country() - Address parts
 * - vizou_event_notes() - Displays the event description/notes
 * - vizou_event_status() - Displays the event status (if not "Active")
 * - vizou_event_tickets_link() - Displays the tickets button with link
 *
 * @package Vizou_Events_Manager
 * @since 0.1.8
 */

// Exit if accessed directly
if (!defined('ABSPATH')) exit;
?>

<!-- This is the default events list template -->
 
<!-- BEGIN EVENT -->
<?php
// Force proper class detection directly in this template
$classes = array('event');

// Directly check if this is a past event
$event_date = get_field('event_start');
if ($event_date) {
    try {
        // First try d/m/Y format (ACF default)
        $event_datetime = DateTime::createFromFormat('d/m/Y', $event_date);
        if (!$event_datetime) {
            // If that fails, try Y-m-d format
            $event_datetime = DateTime::createFromFormat('Y-m-d', $event_date);
        }
        
        if ($event_datetime) {
            // Set time to end of day for consistent comparison
            $event_datetime->setTime(0, 0, 0);
            
            $current_datetime = new DateTime();
            $current_datetime->setTime(0, 0, 0);
            
            if ($event_datetime < $current_datetime) {
                $classes[] = 'event-past';
            }
        }
    } catch (Exception $e) {
        // Fail silently
    }
}

// Check if this is a cancelled event
$event_status = get_field('event_status');
if ($event_status && strcasecmp(trim($event_status), 'cancelled') === 0) {
    $classes[] = 'event-cancelled';
}
?>

<div class="<?php echo esc_attr(implode(' ', array_map('sanitize_html_class', $classes))); ?>">

    <div class="left">

   <!-- DATE, TIME -->
    <p class="event-date">
        <?php 
        // Get the raw date value
        $post_id = get_the_ID();
        $start_date_raw = get_field('event_start', $post_id);
        
        if ($start_date_raw) {
            // First create DateTime object from stored d/m/Y format
            $date_obj = DateTime::createFromFormat('d/m/Y', $start_date_raw);
            if ($date_obj) {
                // Convert to timestamp and use wp_date() which is the WP-approved function
                $timestamp = $date_obj->getTimestamp();
                echo '<span class="event-start-date">' . esc_html(wp_date(get_option('date_format'), $timestamp)) . '</span>';
            }
        }
        
        // Handle end date if present
        $end_date_raw = get_field('event_end', $post_id);
        if (!empty($end_date_raw)) {
            $end_date_obj = DateTime::createFromFormat('d/m/Y', $end_date_raw);
            if ($end_date_obj) {
                $end_timestamp = $end_date_obj->getTimestamp();
                echo '<span class="event-end-date"> - ' . esc_html(wp_date(get_option('date_format'), $end_timestamp)) . '</span>';
            }
        }
        ?>

        <?php 
        // Add time, but only if it exists
        $time = get_field('event_time', $post_id);
        if (!empty($time)): 
        ?>
            <span class="event-time"> - <?php echo esc_html($time); ?></span>
        <?php endif; ?>
    </p>

       <!-- TITLE (VENUE, ARTIST) -->
        <h3>
            <?php 
            // Display format depends on the setting
            $display_format = Vizou_Events_Settings::get_option('display_format');
            
            // Check if artist exists
            $has_artist = false;
            $artist_terms = get_the_terms(get_the_ID(), 'artist');
            if (!empty($artist_terms) && !is_wp_error($artist_terms)) {
                $has_artist = true;
            }
            
            if ($display_format === 'artist_first') {
                // Artist first
                if ($has_artist) {
                    vizou_event_artist();
                    echo '<span class="event-venue artist-first">';
                    vizou_event_venue();
                    echo '</span>';
                } else {
                    // Only venue if no artist
                    vizou_event_venue();
                }
            } else {
                // Venue first (default)
                vizou_event_venue();
                if ($has_artist) {
                    echo '<span class="event-artist venue-first">';
                    vizou_event_artist();
                    echo '</span>';
                }
            }
            ?>
        </h3>

        <!-- LOCATION -->
        <p class="event-details">
            <span class="event-address">
                <?php if (vizou_venue_street(null, false)): ?>
                    <span class="event-street"><?php vizou_venue_street(); ?>, </span>
                <?php endif; ?>
                
                <?php if (vizou_venue_city(null, false)): ?>
                    <span class="event-city"><?php vizou_venue_city(); ?>, </span>
                <?php endif; ?>
                
                <?php if (vizou_venue_province(null, false)): ?>
                    <span class="event-province"><?php vizou_venue_province(); ?></span>
                <?php endif; ?>
                
                <?php if (vizou_venue_country(null, false)): ?>
                    <span class="event-country"> (<?php vizou_venue_country(); ?>)</span>
                <?php endif; ?>
            </span>

            <!-- NOTES -->
            <?php if (vizou_event_notes(null, false)): ?>
                <span class="event-notes">
                    <?php vizou_event_notes(); ?>
                </span>
            <?php endif; ?>

            <!-- STATUS -->
            <?php vizou_event_status(); ?>
            <?php edit_post_link(esc_html__('Edit', 'vizou-events-manager'), '', ''); ?>
        </p>

    </div>

    <div class="right">

    <!-- THUMBNAIL -->
        <?php if ((function_exists('has_post_thumbnail')) && (has_post_thumbnail())): ?>
        <a href="<?php echo esc_url($thumb[0]); ?>" title="<?php echo esc_attr(get_the_title()); ?>">
            <img class="event-thumb" 
                src="<?php echo esc_url($thumb[0]); ?>" 
                width="<?php echo esc_attr($thumb[1]); ?>" 
                height="<?php echo esc_attr($thumb[2]); ?>" 
                alt="<?php echo esc_attr($thumb_alt); ?>"
                loading="lazy"/>
        </a>
        <?php endif; ?>

    <!-- TICKETS -->
        <p class="event-tickets">
            <?php vizou_event_tickets_link(); ?>
        </p>

    </div>
</div>