<?php
/**
 * Template: Single Event Template
 *
 * This template displays a single event on its dedicated page.
 * To customize, copy this file to your-theme/single-event.php or your-theme/vizou-events/vizou-single-event.php
 * 
 * This template includes the WordPress header and footer and handles the main query.
 *
 * @package Vizou_Events_Manager
 * @since 0.1.7
 */

// Exit if accessed directly
if (!defined('ABSPATH')) exit;

get_header(); 
?>
	
    <?php if (have_posts()) : while (have_posts()) : the_post(); ?>

        <div class="grid">
            <main class="content">

                <?php
                // Setup thumbnail variables
                $thumb = wp_get_attachment_image_src(get_post_thumbnail_id(), 'large', false);
                $thumb_id = absint(get_post_thumbnail_id());
                $thumb_alt = '';
                if ($thumb_id) {
                    $thumb_alt = sanitize_text_field(get_post_meta($thumb_id, '_wp_attachment_image_alt', true));			
                    if (empty($thumb_alt)) {
                        $attachment = get_post($thumb_id);
                        if ($attachment) {
                            $thumb_alt = sanitize_text_field($attachment->post_title);
                        }
                    }
                }
                
                // Determine classes for the event
                $classes = array('event');
                
                // Check if this is a past event
                if (function_exists('vizou_is_past_event') && vizou_is_past_event()) {
                    $classes[] = 'event-past';
                } else {
                    // Direct implementation as fallback
                    $event_date = get_field('event_start');
                    if ($event_date) {
                        try {
                            // First try d/m/Y format (ACF default)
                            $event_datetime = DateTime::createFromFormat('d/m/Y', $event_date);
                            if (!$event_datetime) {
                                // If that fails, try Y-m-d format
                                $event_datetime = DateTime::createFromFormat('Y-m-d', $event_date);
                            }
                            
                            if ($event_datetime) {
                                // Set time to end of day for consistent comparison
                                $event_datetime->setTime(0, 0, 0);
                                
                                $current_datetime = new DateTime();
                                $current_datetime->setTime(0, 0, 0);
                                
                                if ($event_datetime < $current_datetime) {
                                    $classes[] = 'event-past';
                                }
                            }
                        } catch (Exception $e) {
                            // Fail silently
                        }
                    }
                }
                
                // Check if this is a cancelled event
                if (function_exists('vizou_is_cancelled_event') && vizou_is_cancelled_event()) {
                    $classes[] = 'event-cancelled';
                } else {
                    // Direct implementation as fallback
                    $event_status = get_field('event_status');
                    if ($event_status && strcasecmp(trim($event_status), 'cancelled') === 0) {
                        $classes[] = 'event-cancelled';
                    }
                }
                ?>

                <!-- BEGIN EVENT -->
                <article class="<?php echo esc_attr(implode(' ', array_map('sanitize_html_class', $classes))); ?>">

                    <!-- TICKETS -->
                    <p class="event-tickets">
                        <?php vizou_event_tickets_link(); ?>
                    </p>

                    <!-- DATE, TIME -->
                    <p class="event-date">
                        <?php 
                        // Get both dates to determine if this is a multi-day event
                        $start_date = vizou_event_date(null, false);
                        $end_date = vizou_event_end_date(null, false);
                        
                        // Output date or date range appropriately
                        echo '<span class="event-start-date">' . esc_html($start_date) . '</span>';
                        
                        if (!empty($end_date)) {
                            echo '<span class="event-end-date"> - ' . esc_html($end_date) . '</span>';
                        }
                        ?>

                        <?php if (vizou_event_time()): ?>
                            <span class="event-time"><?php vizou_event_time(); ?></span>
                        <?php endif; ?>
                    </p>

                    <!-- TITLE (VENUE, ARTIST) -->
                    <h1>
                        <?php 
                        // Display format depends on the setting
                        $display_format = Vizou_Events_Settings::get_option('display_format');
                        
                        if ($display_format === 'artist_first') {
                            // Artist first
                            vizou_event_artist();
                            echo ' <span class="event-venue">';
                            vizou_event_venue();
                            echo '</span>';
                        } else {
                            // Venue first (default)
                            vizou_event_venue();
                            echo ' <span class="event-artist">';
                            vizou_event_artist();
                            echo '</span>';
                        }
                        ?>
                    </h1>

                    <!-- LOCATION -->
                    <p class="event-details">
                        <span class="event-address">
                            <?php if (vizou_venue_street(null, false)): ?>
                                <span class="event-street"><?php vizou_venue_street(); ?>, </span>
                            <?php endif; ?>
                            
                            <?php if (vizou_venue_city(null, false)): ?>
                                <span class="event-city"><?php vizou_venue_city(); ?></span>
                            <?php endif; ?>
                            
                            <?php if (vizou_venue_province(null, false)): ?>
                                , <span class="event-province"><?php vizou_venue_province(); ?></span>
                            <?php endif; ?>
                            
                            <?php if (vizou_venue_country(null, false)): ?>
                                <span class="event-country"> (<?php vizou_venue_country(); ?>)</span>
                            <?php endif; ?>
                        </span>
                    </p>

                    <!-- NOTES -->
                    <?php if (vizou_event_notes(null, false)): ?>
                        <div class="event-notes">
                            <?php vizou_event_notes(); ?>
                        </div>
                    <?php endif; ?>

                    <!-- THUMBNAIL -->
                    <?php if ((function_exists('has_post_thumbnail')) && (has_post_thumbnail())) : ?>
                        <a href="<?php echo esc_url(get_permalink()); ?>" title="<?php echo esc_attr(get_the_title()); ?>">
                            <img class="event-thumb" 
                                src="<?php echo esc_url($thumb[0]); ?>" 
                                width="<?php echo esc_attr($thumb[1]); ?>" 
                                height="<?php echo esc_attr($thumb[2]); ?>" 
                                alt="<?php echo esc_attr($thumb_alt); ?>"
                                loading="lazy"/>
                        </a>
                    <?php endif; ?>  

                    <!-- EVENT STATUS -->
                    <?php vizou_event_status(); ?>

                </article>

                <?php edit_post_link(esc_html__('Edit', 'vizou-events-manager'), '', '');?>

            </main>						
        </div>
                    
    <?php endwhile; endif; ?>
        
<?php get_footer(); ?>